From 28cc115ff540dc50bea2d6e23e0098f0f2f752da Mon Sep 17 00:00:00 2001
From: 5chdn <5chdn@users.noreply.github.com>
Date: Sun, 22 Oct 2017 09:26:23 +0200
Subject: [PATCH 1/5] Add license to help, #60
---
cmd/gmc/main.go | 16 +++++++++++++++-
1 file changed, 15 insertions(+), 1 deletion(-)
diff --git a/cmd/gmc/main.go b/cmd/gmc/main.go
index 9041a4354..fab254a36 100644
--- a/cmd/gmc/main.go
+++ b/cmd/gmc/main.go
@@ -140,7 +140,21 @@ func init() {
// Initialize the CLI app and start GMC
app.Action = gmc
app.HideVersion = true // we have a command to print the version
- app.Copyright = "Copyright 2013-2017 The go-ethereum Authors"
+ app.Copyright = `Copyright 2013-2017 The Go-Ethereum Authors
+ Copyright 2016-2017 The Go-Musicoin Authors
+
+ Go-Musicoin is free software: you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation, either version 3 of the License, or
+ (at your option) any later version.
+
+ Go-Musicoin is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with Go-Musicoin. If not, see .`
app.Commands = []cli.Command{
// See chaincmd.go:
initCommand,
From c6f2943ed9cb372f1595d14d9281527048b54082 Mon Sep 17 00:00:00 2001
From: 5chdn <5chdn@users.noreply.github.com>
Date: Sun, 22 Oct 2017 09:58:56 +0200
Subject: [PATCH 2/5] Add copyright notice to help
---
cmd/gmc/usage.go | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/cmd/gmc/usage.go b/cmd/gmc/usage.go
index 71c7594ed..210078655 100644
--- a/cmd/gmc/usage.go
+++ b/cmd/gmc/usage.go
@@ -31,7 +31,8 @@ import (
var AppHelpTemplate = `NAME:
{{.App.Name}} - {{.App.Usage}}
- Copyright 2013-2017 The go-ethereum Authors
+ Copyright 2013-2017 The Go-Ethereum Authors
+ Copyright 2016-2017 The Go-Musicoin Authors
USAGE:
{{.App.HelpName}} [options]{{if .App.Commands}} command [command options]{{end}} {{if .App.ArgsUsage}}{{.App.ArgsUsage}}{{else}}[arguments...]{{end}}
From d3f28fd73983bfead69fe13724604cf08b9171f7 Mon Sep 17 00:00:00 2001
From: 5chdn <5chdn@users.noreply.github.com>
Date: Sun, 22 Oct 2017 10:05:33 +0200
Subject: [PATCH 3/5] Adjust more copyright notices
---
consensus/ethash/consensus.go | 8 ++++++--
core/fees.go | 7 +++++--
params/config.go | 7 +++++--
3 files changed, 16 insertions(+), 6 deletions(-)
diff --git a/consensus/ethash/consensus.go b/consensus/ethash/consensus.go
index d04c42325..7c12e20cc 100644
--- a/consensus/ethash/consensus.go
+++ b/consensus/ethash/consensus.go
@@ -1,5 +1,8 @@
-// Copyright 2017 The go-ethereum Authors
-// This file is part of the go-ethereum library.
+// Copyright 2017 The Go-Ethereum Authors
+// This file is part of the Go-Ethereum library.
+//
+// Copyright 2017 The Go-Musicoin Authors
+// This file is part of the Go-Musicoin library.
//
// The go-ethereum library is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
@@ -550,6 +553,7 @@ func AccumulateRewards(config *params.ChainConfig, state *state.StateDB, header
reward.Add(reward, r)
}
+ // Activate MCIP-3-UBI hardfork
if config.IsUBIFork(header.Number) {
state.AddBalance(header.Coinbase, mcip3Reward)
state.AddBalance(common.HexToAddress("0x00eFdd5883eC628983E9063c7d969fE268BBf310"), ubiReservoir)
diff --git a/core/fees.go b/core/fees.go
index 056f0ed8b..e91a05a8f 100644
--- a/core/fees.go
+++ b/core/fees.go
@@ -1,5 +1,8 @@
-// Copyright 2014 The go-ethereum Authors
-// This file is part of the go-ethereum library.
+// Copyright 2014 The Go-Ethereum Authors
+// This file is part of the Go-Ethereum library.
+//
+// Copyright 2017 The Go-Musicoin Authors
+// This file is part of the Go-Musicoin library.
//
// The go-ethereum library is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
diff --git a/params/config.go b/params/config.go
index 55799d314..c9b989776 100644
--- a/params/config.go
+++ b/params/config.go
@@ -1,5 +1,8 @@
-// Copyright 2016 The go-ethereum Authors
-// This file is part of the go-ethereum library.
+// Copyright 2016 The Go-Ethereum Authors
+// This file is part of the Go-Ethereum library.
+//
+// Copyright 2017 The Go-Musicoin Authors
+// This file is part of the Go-Musicoin library.
//
// The go-ethereum library is free software: you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as published by
From f6ced5de00b488385ef1ed2f17f587f3046b737d Mon Sep 17 00:00:00 2001
From: 5chdn <5chdn@users.noreply.github.com>
Date: Sun, 22 Oct 2017 10:07:54 +0200
Subject: [PATCH 4/5] Proper formatting of MCIP3
---
consensus/ethash/consensus.go | 2 +-
params/config.go | 6 +++---
2 files changed, 4 insertions(+), 4 deletions(-)
diff --git a/consensus/ethash/consensus.go b/consensus/ethash/consensus.go
index 7c12e20cc..372d44fe2 100644
--- a/consensus/ethash/consensus.go
+++ b/consensus/ethash/consensus.go
@@ -553,7 +553,7 @@ func AccumulateRewards(config *params.ChainConfig, state *state.StateDB, header
reward.Add(reward, r)
}
- // Activate MCIP-3-UBI hardfork
+ // Activate MCIP3-UBI hardfork
if config.IsUBIFork(header.Number) {
state.AddBalance(header.Coinbase, mcip3Reward)
state.AddBalance(common.HexToAddress("0x00eFdd5883eC628983E9063c7d969fE268BBf310"), ubiReservoir)
From 105239b9db36f1edd658330e8f5ee01b2b4ff35b Mon Sep 17 00:00:00 2001
From: isaac
Date: Sat, 4 Nov 2017 22:54:57 +0800
Subject: [PATCH 5/5] change version to 2.5.0
---
params/version.go | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/params/version.go b/params/version.go
index f675b1042..bf808969e 100644
--- a/params/version.go
+++ b/params/version.go
@@ -22,7 +22,7 @@ import (
const (
VersionMajor = 2 // Major version component of the current release
- VersionMinor = 1 // Minor version component of the current release
+ VersionMinor = 5 // Minor version component of the current release
VersionPatch = 0 // Patch version component of the current release
VersionMeta = "unstable" // Version metadata to append to the version string
)
diff --git a/params/config.go b/params/config.go
index c9b989776..e2732700d 100644
--- a/params/config.go
+++ b/params/config.go
@@ -154,7 +154,7 @@ func (c *ChainConfig) String() string {
default:
engine = "unknown"
}
- return fmt.Sprintf("{ChainID: %v Homestead: %v MCIP-3 UBI: %v DAO: %v DAOSupport: %v EIP150: %v EIP155: %v EIP158: %v Byzantium: %v Engine: %v}",
+ return fmt.Sprintf("{ChainID: %v Homestead: %v MCIP3-UBI: %v DAO: %v DAOSupport: %v EIP150: %v EIP155: %v EIP158: %v Byzantium: %v Engine: %v}",
c.ChainId,
c.HomesteadBlock,
c.UBIForkBlock,
@@ -173,7 +173,7 @@ func (c *ChainConfig) IsHomestead(num *big.Int) bool {
return isForked(c.HomesteadBlock, num)
}
// IsUBIFork returns whether num is either equal to the MCIP-3 block or greater.
func (c *ChainConfig) IsUBIFork(num *big.Int) bool {
return isForked(c.UBIForkBlock, num)
}
@@ -239,7 +239,7 @@ func (c *ChainConfig) checkCompatible(newcfg *ChainConfig, head *big.Int) *Confi
return newCompatError("Homestead fork block", c.HomesteadBlock, newcfg.HomesteadBlock)
}
if isForkIncompatible(c.UBIForkBlock, newcfg.UBIForkBlock, head) {
- return newCompatError("MCIP-3 UBI fork block", c.UBIForkBlock, newcfg.UBIForkBlock)
+ return newCompatError("MCIP3-UBI fork block", c.UBIForkBlock, newcfg.UBIForkBlock)
}
if isForkIncompatible(c.DAOForkBlock, newcfg.DAOForkBlock, head) {
return newCompatError("DAO fork block", c.DAOForkBlock, newcfg.DAOForkBlock)
@@ -173,7 +173,7 @@ func (c *ChainConfig) IsHomestead(num *big.Int) bool {
return isForked(c.HomesteadBlock, num)
}
-// IsUBIFork returns whether num is either equal to the MCIP-3 block or greater.
+// IsUBIFork returns whether num is either equal to the MCIP3-UBI block or greater.
func (c *ChainConfig) IsUBIFork(num *big.Int) bool {
return isForked(c.UBIForkBlock, num)